@@ -61,7 +61,7 @@
 #define KDECORATIONS2_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECORATIONS2_NO_DEPRECATED
-#  define KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51b06
+#  define KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51b0a
 #endif
 #ifdef KDECORATIONS2_NO_DEPRECATED_WARNINGS
 #  define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0
@@ -71,7 +71,7 @@
 #  ifdef KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE KDECORATIONS2_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0x51b06
+#    define KDECORATIONS2_DEPRECATED_WARNINGS_SINCE 0x51b0a
 #  endif
 #endif
 
